package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnTest;

/**
 * 试卷批次Service接口
 * 
 * @author ruoyi
 * @date 2025-09-18
 */
public interface ILearnTestService 
{
    /**
     * 查询试卷批次
     * 
     * @param batchId 试卷批次主键
     * @return 试卷批次
     */
    public LearnTest selectLearnTestByBatchId(Integer batchId);

    /**
     * 查询试卷批次列表
     * 
     * @param learnTest 试卷批次
     * @return 试卷批次集合
     */
    public List<LearnTest> selectLearnTestList(LearnTest learnTest);

    /**
     * 新增试卷批次
     * 
     * @param learnTest 试卷批次
     * @return 结果
     */
    public int insertLearnTest(LearnTest learnTest);

    /**
     * 修改试卷批次
     * 
     * @param learnTest 试卷批次
     * @return 结果
     */
    public int updateLearnTest(LearnTest learnTest);

    /**
     * 批量删除试卷批次
     * 
     * @param batchIds 需要删除的试卷批次主键集合
     * @return 结果
     */
    public int deleteLearnTestByBatchIds(Integer[] batchIds);

    /**
     * 删除试卷批次信息
     * 
     * @param batchId 试卷批次主键
     * @return 结果
     */
    public int deleteLearnTestByBatchId(Integer batchId);
}
